# frozen_string_literal: true

require 'test_helper'

class ConfigurationTest < Minitest::Test
  def test_configuration_default_values
    new_pii_fields = Set['unknown_field1']

    PIIDetector.configure do |config|
      config.edit_distance = 3
      config.pii_fields += new_pii_fields
    end

    assert_equal 3, PIIDetector.config.edit_distance
    assert new_pii_fields.subset?(PIIDetector.config.pii_fields)

    new_pii_fields.merge(['unknown_field2'])
    PIIDetector.config.edit_distance = 2
    PIIDetector.config.pii_fields += new_pii_fields

    assert_equal 2, PIIDetector.config.edit_distance
    assert new_pii_fields.subset?(PIIDetector.config.pii_fields)
  end

  def test_configuration_set_not_exists_attribute
    assert_raises NoMethodError do
      PIIDetector.configure do |config|
        config.unknown_attribute = 'test'
      end
    end
  end

  def test_configuration_get_not_exists_attribute
    assert_raises NoMethodError do
      PIIDetector.config.unknown_attribute
    end
  end
end
